@@ -3,12 +3,12 @@ from __future__ import annotations
 from typing import TYPE_CHECKING
 
 from simulation.interactables import serialize_interactables
-from simulation.worksheet import WORKSHEET
+from simulation.worksheet.worksheet import get_worksheet_data
 
 if TYPE_CHECKING:
     from simulation.world_map import WorldMap
     from simulation.avatar.avatar_manager import AvatarManager
-    from simulation.worksheet import WorksheetData
+    from simulation.worksheet.worksheet import WorksheetData
 
 
 class GameState:
@@ -16,7 +16,10 @@ class GameState:
     Encapsulates the entire game state, including avatars, their code, and the world.
     """
 
-    def __init__(self, world_map, avatar_manager, worksheet: WorksheetData = WORKSHEET):
+    def __init__(self, world_map, avatar_manager, worksheet: WorksheetData = None):
+        if worksheet is None:
+            worksheet = get_worksheet_data()
+
         self.world_map: WorldMap = world_map
         self.avatar_manager: AvatarManager = avatar_manager
         self.turn_count: int = 0
@@ -25,6 +28,7 @@ class GameState:
     def serialize(self):
         return {
             "era": self.worksheet.era,
+            "worksheetID": self.worksheet.worksheet_id,
             "southWestCorner": self.world_map.get_serialized_south_west_corner(),
             "northEastCorner": self.world_map.get_serialized_north_east_corner(),
             "players": self.avatar_manager.serialize_players(),
