@@ -1,7 +1,9 @@
 import json
 from rest_framework import serializers
 
-from aimmo.models import Game, Avatar, Worksheet
+from aimmo.models import Game, Avatar
+from aimmo.game_manager import GameManager
+from aimmo.worksheets import WORKSHEETS
 
 
 class GameSerializer(serializers.Serializer):
@@ -40,15 +42,24 @@ class GameSerializer(serializers.Serializer):
             "worksheet_id", instance.worksheet_id
         )
 
+        instance.save()
+
         if "worksheet_id" in validated_data:
             avatars = Avatar.objects.filter(game=instance)
-            worksheet = Worksheet.objects.get(id=instance.worksheet_id)
+            worksheet = WORKSHEETS.get(instance.worksheet_id)
 
             for avatar in avatars:
                 avatar.code = worksheet.starter_code
                 avatar.save()
 
-        instance.save()
+            # If the game is running, the game server needs to be restarted
+            if instance.status == Game.RUNNING:
+                game_manager = GameManager()
+                game_manager.recreate_game_server(
+                    game_id=instance.id,
+                    game_data_updates={"worksheet_id": str(instance.worksheet_id)},
+                )
+
         return instance
 
 
