@@ -23,6 +23,7 @@ urlpatterns = [
         name="kurono/statistics",
     ),
     url(r"^api/code/(?P<id>[0-9]+)/$", views.code, name="kurono/code"),
+    url(r"^api/badges/(?P<id>[0-9]+)/$", views.badges, name="kurono/badges"),
     url(
         r"^api/games/(?P<id>[0-9]+)/users/$",
         views.GameUsersView.as_view(),
@@ -38,11 +39,6 @@ urlpatterns = [
         views.connection_parameters,
         name="kurono/connection_parameters",
     ),
-    url(
-        r"^api/games/(?P<id>[0-9]+)/complete/$",
-        views.mark_game_complete,
-        name="kurono/complete_game",
-    ),
     url(r"^api/", include(router.urls)),
     url(
         r"^jsreverse/$", urls_js, name="kurono/js_reverse"
