@@ -56,9 +56,7 @@ def code(request, id):
         avatar.save()
         return HttpResponse()
     else:
-        return JsonResponse(
-            {"code": avatar.code, "starterCode": game.worksheet.starter_code}
-        )
+        return JsonResponse({"code": avatar.code, "starterCode": game.worksheet.starter_code})
 
 
 @login_required
@@ -133,8 +131,7 @@ class GameViewSet(
     @action(methods=["get"], detail=False)
     def running(self, request):
         response = {
-            game.pk: GameSerializer(game).data
-            for game in Game.objects.filter(status=Game.RUNNING, is_archived=False)
+            game.pk: GameSerializer(game).data for game in Game.objects.filter(status=Game.RUNNING, is_archived=False)
         }
         return Response(response)
 
@@ -146,10 +143,14 @@ class GameViewSet(
     )
     def delete_games(self, request):
         game_ids = request.data.getlist("game_ids")
-        games = Game.objects.filter(
-            pk__in=game_ids,
-            game_class__teacher__new_user=request.user,
-            is_archived=False,
+        games = (
+            Game.objects.filter(
+                pk__in=game_ids,
+                game_class__teacher__school=request.user.userprofile.teacher.school,
+                is_archived=False,
+            )
+            if request.user.userprofile.teacher.is_admin
+            else Game.objects.filter(pk__in=game_ids, game_class__teacher__new_user=request.user, is_archived=False)
         )
         for game in games:
             game.is_archived = True  # mark as deleted/archived
@@ -227,21 +228,15 @@ def get_avatar_id(user: User, game_id) -> Tuple[int, HttpResponse]:
     try:
         avatar_id = game_renderer.get_avatar_id_from_user(user=user, game_id=game_id)
     except UserCannotPlayGameException:
-        LOGGER.warning(
-            "HTTP 401 returned. User {} unauthorised to play.".format(user.id)
-        )
+        LOGGER.warning("HTTP 401 returned. User {} unauthorised to play.".format(user.id))
         response = HttpResponse("User unauthorized to play", status=401)
     except Avatar.DoesNotExist:
-        LOGGER.warning(
-            "Avatar does not exist for user {} in game {}".format(user.id, game_id)
-        )
+        LOGGER.warning("Avatar does not exist for user {} in game {}".format(user.id, game_id))
         response = HttpResponse("Avatar does not exist for this user", status=404)
     except Http404 as e:
         response = HttpResponse("Game does not exist", status=404)
     except Exception as e:
         LOGGER.error(f"Unknown error occurred while getting connection parameters: {e}")
-        response = HttpResponse(
-            "Unknown error occurred when getting the current avatar", status=500
-        )
+        response = HttpResponse("Unknown error occurred when getting the current avatar", status=500)
 
     return avatar_id, response
